==> mono_1.1.8.3.orig.tar.gz: mono-1.1.8.3/mcs/class/System.Drawing/System.Drawing/RotateFlipType.cs <==
//
// System.Drawing.RotateFlipType .cs
//
// (C) 2001 Ximian, Inc.  http://www.ximian.com
// Author: Dennis Hayes (dennish@raytek.com)
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
namespace System.Drawing 
{
	[Serializable]
	public enum RotateFlipType {
		RotateNoneFlipNone = 0,
		Rotate180FlipXY    = 0,
		Rotate90FlipNone   = 1,
		Rotate270FlipXY    = 1,
		Rotate180FlipNone  = 2,
		RotateNoneFlipXY   = 2,
		Rotate270FlipNone  = 3,
		Rotate90FlipXY     = 3,
		RotateNoneFlipX    = 4,
		Rotate180FlipY     = 4,
		Rotate90FlipX      = 5,
		Rotate270FlipY     = 5,
		Rotate180FlipX     = 6,
		RotateNoneFlipY    = 6,
		Rotate270FlipX     = 7,
		Rotate90FlipY      = 7,
	}
}

==> mono_4.6.2.7+dfsg.orig.tar.gz: mono-4.6.2+dfsg/mcs/class/System.Drawing/System.Drawing/RotateFlipType.cs <==
//
// System.Drawing.RotateFlipType .cs
//
// Author: Dennis Hayes (dennish@raytek.com)
//
// (C) 2001 Ximian, Inc.  http://www.ximian.com
// Copyright (C) 2004,2006 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace System.Drawing {

	public enum RotateFlipType {
		RotateNoneFlipNone = 0,
		Rotate180FlipXY    = 0,
		Rotate90FlipNone   = 1,
		Rotate270FlipXY    = 1,
		Rotate180FlipNone  = 2,
		RotateNoneFlipXY   = 2,
		Rotate270FlipNone  = 3,
		Rotate90FlipXY     = 3,
		RotateNoneFlipX    = 4,
		Rotate180FlipY     = 4,
		Rotate90FlipX      = 5,
		Rotate270FlipY     = 5,
		Rotate180FlipX     = 6,
		RotateNoneFlipY    = 6,
		Rotate270FlipX     = 7,
		Rotate90FlipY      = 7,
	}
}
